==> 0.0.8.tar.gz: lib/yundian_alive_method_channel.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'yundian_alive_platform_interface.dart';

/// An implementation of [YundianAlivePlatform] that uses method channels.
class MethodChannelYundianAlive extends YundianAlivePlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('yundian_alive');

  final aliveResultListener = const EventChannel('yundian_alive.event.alive.result_listener');

  @override
  Future<String?> getPlatformVersion() async {
    final version = await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> aliveEncryptAes(Map map) async {
    final version = await methodChannel.invokeMethod<String>('alive_encrypt_aes', map);
    return version;
  }

  @override
  Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) async {
    var parameters = {"isDebug": isDebug, "appKey": appKey, "mchInfo": mchInfo, "riskInfo": riskInfo};
    final version = await methodChannel.invokeMethod<String>('alive_init', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage) async {
    var parameters = {"authToken": authToken, "distance": distance, "hasResultPage": hasResultPage};
    final version = await methodChannel.invokeMethod<String>('alive_start_detect', Map.from(parameters));
    return version;
  }

  @override
  onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    aliveResultListener.receiveBroadcastStream().listen(onEvent, onError: onError);
  }

  @override
  Future<String?> aliveRelease() async {
    final version = await methodChannel.invokeMethod<String>('aliveRelease');
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedFailId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedPreId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedSuccessId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setTimeout(int timeout) async {
    var parameters = {"timeout": timeout};
    final version = await methodChannel.invokeMethod<String>('setTimeout', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> aliveActionSize(int actionSize) async {
    var parameters = {"actionSize": actionSize};
    final version = await methodChannel.invokeMethod<String>('aliveActionSize', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> aliveSecurityLevel(int securityLevel) async {
    var parameters = {"securityLevel": securityLevel};
    final version = await methodChannel.invokeMethod<String>('aliveSecurityLevel', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> aliveActionSecond(int actionSecond) async {
    var parameters = {"actionSecond": actionSecond};
    final version = await methodChannel.invokeMethod<String>('aliveActionSecond', Map.from(parameters));
    return version;
  }
}

typedef EventHandler = void Function(dynamic event);

==> 0.1.3.tar.gz: lib/yundian_alive_method_channel.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/services.dart';

import 'yundian_alive_platform_interface.dart';

/// An implementation of [YundianAlivePlatform] that uses method channels.
class MethodChannelYundianAlive extends YundianAlivePlatform {
  /// The method channel used to interact with the native platform.
  @visibleForTesting
  final methodChannel = const MethodChannel('yundian_alive');

  final aliveResultListener = const EventChannel('yundian_alive.event.alive.result_listener');

  @override
  Future<String?> getPlatformVersion() async {
    final version = await methodChannel.invokeMethod<String>('getPlatformVersion');
    return version;
  }

  @override
  Future<String?> aliveEncryptAes(Map map) async {
    final version = await methodChannel.invokeMethod<String>('alive_encrypt_aes', map);
    return version;
  }

  @override
  Future<String?> aliveInit(bool isDebug, String appKey, String mchInfo, String riskInfo) async {
    var parameters = {"isDebug": isDebug, "appKey": appKey, "mchInfo": mchInfo, "riskInfo": riskInfo};
    final version = await methodChannel.invokeMethod<String>('alive_init', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> aliveStartDetect(String authToken, double distance, bool hasResultPage) async {
    var parameters = {"authToken": authToken, "distance": distance, "hasResultPage": hasResultPage};
    final version = await methodChannel.invokeMethod<String>('alive_start_detect', Map.from(parameters));
    return version;
  }

  @override
  onAliveResultListener(EventHandler onEvent, EventHandler onError) {
    aliveResultListener.receiveBroadcastStream().listen(onEvent, onError: onError);
  }

  @override
  Future<String?> aliveRelease() async {
    final version = await methodChannel.invokeMethod<String>('aliveRelease');
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedFailId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedFailId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedPreId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedPreId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setLayoutAliveDetectedSuccessId(String layoutIdName) async {
    var parameters = {"layoutIdName": layoutIdName};
    final version = await methodChannel.invokeMethod<String>('setLayoutAliveDetectedSuccessId', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setTimeout(int timeout) async {
    var parameters = {"timeout": timeout};
    final version = await methodChannel.invokeMethod<String>('setTimeout', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setActionSize(int actionSize) async {
    var parameters = {"actionSize": actionSize};
    final version = await methodChannel.invokeMethod<String>('setActionSize', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setSecurityLevel(int securityLevel) async {
    var parameters = {"securityLevel": securityLevel};
    final version = await methodChannel.invokeMethod<String>('setSecurityLevel', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setActionSecond(int actionSecond) async {
    var parameters = {"actionSecond": actionSecond};
    final version = await methodChannel.invokeMethod<String>('setActionSecond', Map.from(parameters));
    return version;
  }

  @override
  Future<String?> setActionTps(String blinkEyes, String turnHeadNod, String openMouth, String shakeHead) async {
    var parameters = {
      "blink_eyes": blinkEyes,
      "turn_head_nod": turnHeadNod,
      "open_mouth": openMouth,
      "shake_head": shakeHead
    };
    final version = await methodChannel.invokeMethod<String>('setActionTps', Map.from(parameters));
    return version;
  }
}

typedef EventHandler = void Function(dynamic event);
